@@ -1,5 +1,5 @@
 """OSEF private types definition."""
-__version__ = "1.6.1"
+__version__ = "1.11.0"
 
 # Standard imports
 from enum import Enum, IntEnum
@@ -16,7 +16,7 @@ class OsefTypes(IntEnum):
     NUMBER_OF_POINTS = 2
     SPHERICAL_COORDINATES = 3
     REFLECTIVITIES = 4
-    BACKGROUND_FLAGS = 5
+    _BACKGROUND_FLAGS = 5
     CARTESIAN_COORDINATES = 6
     _BGR_COLORS = 7
     _OBJECT_DETECTION_FRAME = 8
@@ -69,7 +69,7 @@ class OsefTypes(IntEnum):
     ZONE_VERTICAL_LIMITS = 56
     GEOGRAPHIC_POSE_PRECISE = 57
     _ROAD_MARKINGS_BITS = 58
-    _SMOOTHED_POSE = 59
+    SMOOTHED_POSE = 59
     _INTERACTIVE_REQUEST = 60
     _INTERACTIVE_RESPONSE = 61
     _INTERACTIVE_REQUEST_ID = 62
@@ -89,6 +89,16 @@ class OsefTypes(IntEnum):
     _BACKGROUND_SCENE_FRAGMENT = 76
     _BACKGROUND_SCENE_FRAGMENT_INFO = 77
     _BACKGROUND_SCENE_FRAGMENT_DISTANCES = 78
+    GEOGRAPHIC_POSE_ARRAY = 79
+    GEOGRAPHIC_SPEED = 80
+    GEOGRAPHIC_SPEED_ARRAY = 81
+    _INSTANTANEOUS_TRANSLATION_SPEED = 82
+    _INSTANTANEOUS_ROTATION_SPEED = 83
+    _FILTERED_TRANSLATION_SPEED = 84
+    _FILTERED_ROTATION_SPEED = 85
+    REFERENCE_MAP_BITS = 86
+    _CARTESIAN_COVARIANCE = 87
+    _CYLINDRICAL_COVARIANCE = 88
 
 
 class OsefKeys(Enum):
@@ -119,6 +129,7 @@ class OsefKeys(Enum):
     - none or one:     Distances                      (DISTANCES)
     - none or one:     Road Markings Bits             (ROAD_MARKINGS_BITS)
     - none or one:     Carla Tag Array                (CARLA_TAG_ARRAY)
+    - none or one:     Reference Map Bits             (REFERENCE_MAP_BITS)
     """
     AUGMENTED_CLOUD = "augmented_cloud"
 
@@ -159,7 +170,7 @@ class OsefKeys(Enum):
     On the contrary the foreground is composed of objects that were not seen before (i.e. they appeared recently and/or
     they are moving).
     """
-    BACKGROUND_FLAGS = "background_flags"
+    _BACKGROUND_FLAGS = "background_flags"
 
     """
     Cartesian Coordinates
@@ -355,6 +366,7 @@ class OsefKeys(Enum):
     - none or one:     Pose                           (POSE)
     - none or one:     Geographic Pose                (GEOGRAPHIC_POSE)
     - none or one:     Geographic Pose Precise        (GEOGRAPHIC_POSE_PRECISE)
+    - none or one:     Geographic Speed               (GEOGRAPHIC_SPEED)
     - none or one:     Ego Motion                     (EGO_MOTION)
     - none or one:     Tracked Objects                (TRACKED_OBJECTS)
     - none or one:     Zones Def                      (ZONES_DEF)
@@ -379,6 +391,8 @@ class OsefKeys(Enum):
     - none or one:     Pose Array                     (POSE_ARRAY)
     - none or one:     Slam Pose Array                (SLAM_POSE_ARRAY)
     - none or one:     Object Properties              (OBJECT_PROPERTIES)
+    - none or one:     Geographic Pose Array          (GEOGRAPHIC_POSE_ARRAY)
+    - none or one:     Geographic Speed Array         (GEOGRAPHIC_SPEED_ARRAY)
     """
     TRACKED_OBJECTS = "tracked_objects"
 
@@ -600,6 +614,12 @@ class OsefKeys(Enum):
     - none or one:     Predicted Position             (PREDICTED_POSITION)
     - none or one:     Smoothed Pose                  (SMOOTHED_POSE)
     - none or one:     Divergence Indicator           (DIVERGENCE_INDICATOR)
+    - none or one:     Instantaneous Translation Speed (INSTANTANEOUS_TRANSLATION_SPEED)
+    - none or one:     Instantaneous Rotation Speed   (INSTANTANEOUS_ROTATION_SPEED)
+    - none or one:     Filtered Translation Speed     (FILTERED_TRANSLATION_SPEED)
+    - none or one:     Filtered Rotation Speed        (FILTERED_ROTATION_SPEED)
+    - none or one:     Cartesian covariance           (CARTESIAN_COVARIANCE)
+    - none or one:     Cylindrical covariance         (CYLINDRICAL_COVARIANCE)
     """
     EGO_MOTION = "ego_motion"
 
@@ -768,12 +788,11 @@ class OsefKeys(Enum):
 
     """
     Smoothed Pose
-    **Output when**: SLAM and slam.smooth_output pose are enabled.
-    **Purpose**: Smoothed pose of the absolute LiDAR pose, to use when speed of the vehicle is low as filtering will
-    introduce a slight delay.
+    **Output when**: SLAM is enabled.
+    **Purpose**: Smoothed pose of the absolute LiDAR pose will introduce a slight delay.
     **Format**: Concatenation of 12 floats of 32-bits each, see type Pose for more details.
     """
-    _SMOOTHED_POSE = "smoothed_pose"
+    SMOOTHED_POSE = "smoothed_pose"
 
     """
     Interactive Request
@@ -850,7 +869,7 @@ class OsefKeys(Enum):
     ground, a motion point or any other flag.
     A point of the cloud is associated with a cell if its projected point on the grid is in the cell.
     The height map provides one height information per cell, the height value depends on the way it is computed by the
-    app (a cell vith no points will have a nan value).
+    app (a cell with no points will have a nan value).
     The Height Map Points is defined as an array of points, with one point per cell of the height map.
     The x and y coordinates represent the center of the cell in the Lidar frame, the third value is the height of the
     cell computed by the app with the points of the cell.
@@ -864,7 +883,7 @@ class OsefKeys(Enum):
     """
     Divergence Indicator
     **Since**: 5.6.0
-    **Output when**: Relocalization is enabled (SLAM with a reference map).
+    **Output when**: Ego-Motion or Relocalization is enabled.
     **Format**: One float value.
     **Purpose**: Indicates if SLAM seems to have diverged.
     - 0 means SLAM algorithm does not seem to have diverged.
@@ -933,6 +952,104 @@ class OsefKeys(Enum):
     """
     _BACKGROUND_SCENE_FRAGMENT_DISTANCES = "background_scene_fragment_distances"
 
+    """
+    Geographic Pose Array
+    **Output when**: Tracking is enabled and georeferencing is activated.
+    **Purpose**: Represents the geographic pose, output from the relocalization processing, expressed in decimal
+    degrees notation (latitude, longitude & heading) of each tracked object.
+    **Format**: Concatenation of 2 double precision (64 bits) and a single precision (32 bits) floats [lat, long,
+    heading], one for each tracked object.
+    * Double-precision floating-point (float64): latitude in decimal degrees, range [ -90.0 .. 90.0 ]
+    * Double-precision floating-point (float64): longitude in decimal degrees, range [ -180.0 .. 180.0 ]
+    * Single-precision floating-point (float32): heading in decimal degrees, range [ 0.0 .. 360.0 [
+    """
+    GEOGRAPHIC_POSE_ARRAY = "geographic_pose_array"
+
+    """
+    Geographic Speed
+    **Output when**: Georeferencing is activated.
+    **Purpose**: Represents speed of mobile platform (on which LiDAR is mounted) as speed in m/s and geographic heading
+    in decimal degrees.
+    **Format**: Concatenation of two single-precision (32-bits) floats per object:
+    * v: absolute speed in meters per second, range [ 0 .. +inf ]
+    * heading: speed vector heading in decimal degrees, range [ 0.0 .. 360.0 [
+    """
+    GEOGRAPHIC_SPEED = "geographic_speed"
+
+    """
+    Geographic Speed Array
+    **Output when**: Tracking is enabled and georeferencing is activated.
+    **Purpose**: Represents speed of tracked objects represented as speed in m/s and geographic heading in decimal
+    degrees.
+    **Format**: Array of geographic speeds, two single-precision (32 bits) floats per object:
+    * v: absolute speed in meters per second, range [ 0 .. +inf ]
+    * heading: speed vector heading in decimal degrees, range [ 0.0 .. 360.0 [
+    """
+    GEOGRAPHIC_SPEED_ARRAY = "geographic_speed_array"
+
+    """
+    Instantaneous Translation Speed
+    **Output when**: SLAM is enabled and its speed_measurement module is enabled.
+    **Purpose**: Represents the instantaneous translation speed of the device (m/s).
+    **Format**: Array of 3 single precision (32 bits) floats, representing the translation speed on each direction.
+    """
+    _INSTANTANEOUS_TRANSLATION_SPEED = "instantaneous_translation_speed"
+
+    """
+    Instantaneous Rotation Speed
+    **Output when**: SLAM is enabled and its speed_measurement module is enabled.
+    **Purpose**: Represents the instantaneous rotation speed of the device (rad/s).
+    **Format**: Array of 3 single precision (32 bits) floats, representing the rotation speed around each axis.
+    """
+    _INSTANTANEOUS_ROTATION_SPEED = "instantaneous_rotation_speed"
+
+    """
+    Filtered Translation Speed
+    **Output when**: SLAM is enabled and its speed_measurement module is enabled.
+    **Purpose**: Represents the filtered translation speed of the device (m/s). An averaging filter smooths the
+    evolution of the speed. A short delay will appear due to the filtering (usually around 1 sec).
+    **Format**: Array of 3 single precision (32 bits) floats, representing the translation speed on each direction.
+    """
+    _FILTERED_TRANSLATION_SPEED = "filtered_translation_speed"
+
+    """
+    Filtered Rotation Speed
+    **Output when**: SLAM is enabled and its speed_measurement module is enabled.
+    **Purpose**: Represents the filtered rotation speed of the device (rad/s). An averaging filter smooths the
+    evolution of the speed. A short delay will appear due to the filtering (usually around 1 sec).
+    **Format**: Array of 3 single precision (32 bits) floats, representing the rotation speed around each axis.
+    """
+    _FILTERED_ROTATION_SPEED = "filtered_rotation_speed"
+
+    """
+    Reference Map Bits
+    **Output when**: SLAM is enabled and its mapping module is enabled.
+    **Purpose**: SLAM identifies potential points of interest within the point cloud, and the mapping module selects
+    some of them to build the map. Theses bits identify the points that are selected to generate the output map.
+    **Format**: Padded list of bits, 1 bit per point of the cloud. If the bit is set, the point is part of the
+    reference map.
+    """
+    REFERENCE_MAP_BITS = "reference_map_bits"
+
+    """
+    Cartesian covariance
+    **Output when**: SLAM is enabled and compute_covariance option is set to true.
+    **Purpose**: Represents the cartesian covariances (m²). It estimates the confidence of the algorithm, and how
+    trustworthy is the position.
+    **Format**: Array of 3 single precision (32 bits) floats, representing the covariance of x, y and z measurements.
+    """
+    _CARTESIAN_COVARIANCE = "cartesian_covariance"
+
+    """
+    Cylindrical covariance
+    **Output when**: SLAM is enabled and compute_covariance option is set to true.
+    **Purpose**: Represents the cylindrical covariances (°²). It estimates the confidence of the algorithm, and how
+    trustworthy is the orientation.
+    **Format**: Array of 3 single precision (32 bits) floats, representing the covariance of roll (rotation around X
+    axis), pitch (rotation around Y axis) and yaw (rotation around Z axis) measurements.
+    """
+    _CYLINDRICAL_COVARIANCE = "cylindrical_covariance"
+
 
 class ClassId(IntEnum):
     """Tracked object class ID"""
@@ -989,6 +1106,9 @@ class LidarModelId(IntEnum):
     FAKE_LIDAR = 16
     HESAI_PANDARXT32M2X = 17
     ROBOSENSE_M1 = 18
+    LIVOX_HAP_TX = 19
+    INNOVIZ_ONE_EAGLE = 20
+    INNOVIZ_ONE_FALCON = 21
 
 
 class CarlaTag(IntEnum):
