@@ -49,8 +49,8 @@ outsight_types = {
             _unpackers._get_array_unpacker(np.dtype(np.uint8)), _packers._array_packer
         ),
     ),
-    OsefTypes.BACKGROUND_FLAGS.value: TypeInfo(
-        OsefKeys.BACKGROUND_FLAGS.value,
+    OsefTypes._BACKGROUND_FLAGS.value: TypeInfo(
+        OsefKeys._BACKGROUND_FLAGS.value,
         LeafInfo(
             _unpackers._get_array_unpacker(np.dtype(bool)), _packers._array_packer
         ),
@@ -393,8 +393,8 @@ outsight_types = {
         OsefKeys._ROAD_MARKINGS_BITS.value,
         LeafInfo(_unpackers._bool_bitfield_unpacker, _packers._bool_bitfield_packer),
     ),
-    OsefTypes._SMOOTHED_POSE.value: TypeInfo(
-        OsefKeys._SMOOTHED_POSE.value,
+    OsefTypes.SMOOTHED_POSE.value: TypeInfo(
+        OsefKeys.SMOOTHED_POSE.value,
         LeafInfo(_unpackers._pose_unpacker, _packers._pose_packer),
     ),
     OsefTypes._HEIGHT_MAP.value: TypeInfo(
@@ -419,6 +419,155 @@ outsight_types = {
             _unpackers._get_array_unpacker(np.dtype(np.uint32)), _packers._array_packer
         ),
     ),
+    OsefTypes._BACKGROUND_SCENE_PARAMS.value: TypeInfo(
+        OsefKeys._BACKGROUND_SCENE_PARAMS.value, InternalNodeInfo(dict)
+    ),
+    OsefTypes._BACKGROUND_SCENE_PARAMS_GENERAL.value: TypeInfo(
+        OsefKeys._BACKGROUND_SCENE_PARAMS_GENERAL.value,
+        LeafInfo(
+            _unpackers._get_structured_array_unpacker(
+                np.dtype(
+                    (
+                        [
+                            ("width", np.uint32),
+                            ("height", np.uint32),
+                            ("first_azimuth", np.float32),
+                            ("azimuth_step", np.float32),
+                        ]
+                    )
+                )
+            ),
+            _packers._structured_array_packer,
+        ),
+    ),
+    OsefTypes._BACKGROUND_SCENE_PARAMS_ELEVATIONS.value: TypeInfo(
+        OsefKeys._BACKGROUND_SCENE_PARAMS_ELEVATIONS.value,
+        LeafInfo(
+            _unpackers._get_array_unpacker(np.dtype(np.float32)),
+            _packers._array_packer,
+        ),
+    ),
+    OsefTypes._BACKGROUND_SCENE_FRAGMENT.value: TypeInfo(
+        OsefKeys._BACKGROUND_SCENE_FRAGMENT.value, InternalNodeInfo(dict)
+    ),
+    OsefTypes._BACKGROUND_SCENE_FRAGMENT_INFO.value: TypeInfo(
+        OsefKeys._BACKGROUND_SCENE_FRAGMENT_INFO.value,
+        LeafInfo(
+            _unpackers._get_structured_array_unpacker(
+                np.dtype(
+                    (
+                        [
+                            ("first_index", np.uint32),
+                            ("cells_number", np.uint32),
+                        ]
+                    )
+                )
+            ),
+            _packers._structured_array_packer,
+        ),
+    ),
+    OsefTypes._BACKGROUND_SCENE_FRAGMENT_DISTANCES.value: TypeInfo(
+        OsefKeys._BACKGROUND_SCENE_FRAGMENT_DISTANCES.value,
+        LeafInfo(
+            _unpackers._get_array_unpacker(np.dtype(np.float32)),
+            _packers._array_packer,
+        ),
+    ),
+    OsefTypes.GEOGRAPHIC_POSE_ARRAY.value: TypeInfo(
+        OsefKeys.GEOGRAPHIC_POSE_ARRAY.value,
+        LeafInfo(
+            _unpackers._get_structured_array_unpacker(
+                np.dtype(
+                    (
+                        [
+                            ("lat", np.float64),
+                            ("long", np.float64),
+                            ("heading", np.float32),
+                        ]
+                    )
+                )
+            ),
+            _packers._structured_array_packer,
+        ),
+    ),
+    OsefTypes.GEOGRAPHIC_SPEED.value: TypeInfo(
+        OsefKeys.GEOGRAPHIC_SPEED.value,
+        LeafInfo(
+            _unpackers._get_structured_array_unpacker(
+                np.dtype(
+                    (
+                        [
+                            ("speed", np.float32),
+                            ("heading", np.float32),
+                        ]
+                    )
+                )
+            ),
+            _packers._structured_array_packer,
+        ),
+    ),
+    OsefTypes.GEOGRAPHIC_SPEED_ARRAY.value: TypeInfo(
+        OsefKeys.GEOGRAPHIC_SPEED_ARRAY.value,
+        LeafInfo(
+            _unpackers._get_structured_array_unpacker(
+                np.dtype(
+                    (
+                        [
+                            ("speed", np.float32),
+                            ("heading", np.float32),
+                        ]
+                    )
+                )
+            ),
+            _packers._structured_array_packer,
+        ),
+    ),
+    OsefTypes._INSTANTANEOUS_TRANSLATION_SPEED.value: TypeInfo(
+        OsefKeys._INSTANTANEOUS_TRANSLATION_SPEED.value,
+        LeafInfo(
+            _unpackers._get_array_unpacker(np.dtype(np.float32)),
+            _packers._array_packer,
+        ),
+    ),
+    OsefTypes._INSTANTANEOUS_ROTATION_SPEED.value: TypeInfo(
+        OsefKeys._INSTANTANEOUS_ROTATION_SPEED.value,
+        LeafInfo(
+            _unpackers._get_array_unpacker(np.dtype(np.float32)),
+            _packers._array_packer,
+        ),
+    ),
+    OsefTypes._FILTERED_TRANSLATION_SPEED.value: TypeInfo(
+        OsefKeys._FILTERED_TRANSLATION_SPEED.value,
+        LeafInfo(
+            _unpackers._get_array_unpacker(np.dtype(np.float32)),
+            _packers._array_packer,
+        ),
+    ),
+    OsefTypes._FILTERED_ROTATION_SPEED.value: TypeInfo(
+        OsefKeys._FILTERED_ROTATION_SPEED.value,
+        LeafInfo(
+            _unpackers._get_array_unpacker(np.dtype(np.float32)),
+            _packers._array_packer,
+        ),
+    ),
+    OsefTypes.REFERENCE_MAP_BITS.value: TypeInfo(
+        OsefKeys.REFERENCE_MAP_BITS.value,
+        LeafInfo(_unpackers._bool_bitfield_unpacker, _packers._bool_bitfield_packer),
+    ),
+    OsefTypes._CARTESIAN_COVARIANCE.value: TypeInfo(
+        OsefKeys._CARTESIAN_COVARIANCE.value,
+        LeafInfo(
+            _unpackers._get_array_unpacker(np.dtype(np.float32)),
+            _packers._array_packer,
+        ),
+    ),
+    OsefTypes._CYLINDRICAL_COVARIANCE.value: TypeInfo(
+        OsefKeys._CYLINDRICAL_COVARIANCE.value,
+        LeafInfo(
+            _unpackers._get_array_unpacker(np.dtype(np.float32)),
+            _packers._array_packer,
+        ),
+    ),
 }
 
 
